@@ -3,11 +3,11 @@ import typing
 import bpy.types
 
 
-def cyclic_toggle(direction: typing.Union[str, int] = 'CYCLIC_U'):
+def cyclic_toggle(direction: typing.Union[int, str] = 'CYCLIC_U'):
     ''' Make active spline closed/opened loop
 
     :param direction: Direction, Direction to make surface cyclic in
-    :type direction: typing.Union[str, int]
+    :type direction: typing.Union[int, str]
     '''
 
     pass
@@ -29,11 +29,11 @@ def de_select_last():
     pass
 
 
-def delete(type: typing.Union[str, int] = 'VERT'):
+def delete(type: typing.Union[int, str] = 'VERT'):
     ''' Delete selected control points or segments
 
     :param type: Type, Which elements to delete
-    :type type: typing.Union[str, int]
+    :type type: typing.Union[int, str]
     '''
 
     pass
@@ -48,7 +48,7 @@ def dissolve_verts():
 
 
 def draw(error_threshold: float = 0.0,
-         fit_method: typing.Union[str, int] = 'REFIT',
+         fit_method: typing.Union[int, str] = 'REFIT',
          corner_angle: float = 1.22173,
          use_cyclic: bool = True,
          stroke: typing.Union[typing.List['bpy.types.OperatorStrokeElement'],
@@ -59,7 +59,7 @@ def draw(error_threshold: float = 0.0,
     :param error_threshold: Error, Error distance threshold (in object units)
     :type error_threshold: float
     :param fit_method: Fit Method * REFIT Refit, Incrementally re-fit the curve (high quality). * SPLIT Split, Split the curve until the tolerance is met (fast).
-    :type fit_method: typing.Union[str, int]
+    :type fit_method: typing.Union[int, str]
     :param corner_angle: Corner Angle
     :type corner_angle: float
     :param use_cyclic: Cyclic
@@ -91,11 +91,11 @@ def duplicate_move(CURVE_OT_duplicate=None, TRANSFORM_OT_translate=None):
     pass
 
 
-def extrude(mode: typing.Union[str, int] = 'TRANSLATION'):
+def extrude(mode: typing.Union[int, str] = 'TRANSLATION'):
     ''' Extrude selected control point(s)
 
     :param mode: Mode
-    :type mode: typing.Union[str, int]
+    :type mode: typing.Union[int, str]
     '''
 
     pass
@@ -111,11 +111,11 @@ def extrude_move(CURVE_OT_extrude=None, TRANSFORM_OT_translate=None):
     pass
 
 
-def handle_type_set(type: typing.Union[str, int] = 'AUTOMATIC'):
+def handle_type_set(type: typing.Union[int, str] = 'AUTOMATIC'):
     ''' Set type of handles for selected control points
 
     :param type: Type, Spline type
-    :type type: typing.Union[str, int]
+    :type type: typing.Union[int, str]
     '''
 
     pass
@@ -320,11 +320,11 @@ def reveal():
     pass
 
 
-def select_all(action: typing.Union[str, int] = 'TOGGLE'):
+def select_all(action: typing.Union[int, str] = 'TOGGLE'):
     ''' (De)select all control points
 
     :param action: Action, Selection action to execute * TOGGLE Toggle, Toggle selection for all elements. * SELECT Select, Select all elements. * DESELECT Deselect, Deselect all elements. * INVERT Invert, Invert selection of all elements.
-    :type action: typing.Union[str, int]
+    :type action: typing.Union[int, str]
     '''
 
     pass
@@ -396,7 +396,7 @@ def select_previous():
 
 def select_random(percent: float = 50.0,
                   seed: int = 0,
-                  action: typing.Union[str, int] = 'SELECT'):
+                  action: typing.Union[int, str] = 'SELECT'):
     ''' Randomly select some control points
 
     :param percent: Percent, Percentage of objects to select randomly
@@ -404,7 +404,7 @@ def select_random(percent: float = 50.0,
     :param seed: Random Seed, Seed for the random number generator
     :type seed: int
     :param action: Action, Selection action to execute * SELECT Select, Select all elements. * DESELECT Deselect, Deselect all elements.
-    :type action: typing.Union[str, int]
+    :type action: typing.Union[int, str]
     '''
 
     pass
@@ -418,15 +418,15 @@ def select_row():
     pass
 
 
-def select_similar(type: typing.Union[str, int] = 'WEIGHT',
-                   compare: typing.Union[str, int] = 'EQUAL',
+def select_similar(type: typing.Union[int, str] = 'WEIGHT',
+                   compare: typing.Union[int, str] = 'EQUAL',
                    threshold: float = 0.1):
     ''' Select similar curve points by property type
 
     :param type: Type
-    :type type: typing.Union[str, int]
+    :type type: typing.Union[int, str]
     :param compare: Compare
-    :type compare: typing.Union[str, int]
+    :type compare: typing.Union[int, str]
     :param threshold: Threshold
     :type threshold: float
     '''
@@ -511,12 +511,12 @@ def spin(center: typing.List[float] = (0.0, 0.0, 0.0),
     pass
 
 
-def spline_type_set(type: typing.Union[str, int] = 'POLY',
+def spline_type_set(type: typing.Union[int, str] = 'POLY',
                     use_handles: bool = False):
     ''' Set type of active spline
 
     :param type: Type, Spline type
-    :type type: typing.Union[str, int]
+    :type type: typing.Union[int, str]
     :param use_handles: Handles, Use handles when converting bezier curves into polygons
     :type use_handles: bool
     '''
