@@ -27,11 +27,11 @@ def brush_add():
     pass
 
 
-def brush_change(brush: typing.Union[str, int] = 'DEFAULT'):
+def brush_change(brush: typing.Union[int, str] = 'DEFAULT'):
     ''' Change active Grease Pencil drawing brush
 
     :param brush: Grease Pencil Brush
-    :type brush: typing.Union[str, int]
+    :type brush: typing.Union[int, str]
     '''
 
     pass
@@ -45,11 +45,11 @@ def brush_copy():
     pass
 
 
-def brush_move(type: typing.Union[str, int] = 'UP'):
+def brush_move(type: typing.Union[int, str] = 'UP'):
     ''' Move the active Grease Pencil drawing brush up/down in the list
 
     :param type: Type
-    :type type: typing.Union[str, int]
+    :type type: typing.Union[int, str]
     '''
 
     pass
@@ -96,11 +96,11 @@ def brush_select(index: int = 0):
     pass
 
 
-def convert(type: typing.Union[str, int] = 'PATH',
+def convert(type: typing.Union[int, str] = 'PATH',
             use_normalize_weights: bool = True,
             radius_multiplier: float = 1.0,
             use_link_strokes: bool = True,
-            timing_mode: typing.Union[str, int] = 'FULL',
+            timing_mode: typing.Union[int, str] = 'FULL',
             frame_range: int = 100,
             start_frame: int = 1,
             use_realtime: bool = False,
@@ -112,7 +112,7 @@ def convert(type: typing.Union[str, int] = 'PATH',
     ''' Convert the active Grease Pencil layer to a new Curve Object
 
     :param type: Type, Which type of curve to convert to * PATH Path, Animation path. * CURVE Bezier Curve, Smooth Bezier curve. * POLY Polygon Curve, Bezier curve with straight-line segments (vector handles).
-    :type type: typing.Union[str, int]
+    :type type: typing.Union[int, str]
     :param use_normalize_weights: Normalize Weight, Normalize weight (set from stroke width)
     :type use_normalize_weights: bool
     :param radius_multiplier: Radius Fac, Multiplier for the points' radii (set from stroke width)
@@ -120,7 +120,7 @@ def convert(type: typing.Union[str, int] = 'PATH',
     :param use_link_strokes: Link Strokes, Whether to link strokes with zero-radius sections of curves
     :type use_link_strokes: bool
     :param timing_mode: Timing Mode, How to use timing data stored in strokes * NONE No Timing, Ignore timing. * LINEAR Linear, Simple linear timing. * FULL Original, Use the original timing, gaps included. * CUSTOMGAP Custom Gaps, Use the original timing, but with custom gap lengths (in frames).
-    :type timing_mode: typing.Union[str, int]
+    :type timing_mode: typing.Union[int, str]
     :param frame_range: Frame Range, The duration of evaluation of the path control curve
     :type frame_range: int
     :param start_frame: Start Frame, The start frame of the path control curve
@@ -166,11 +166,11 @@ def data_unlink():
     pass
 
 
-def delete(type: typing.Union[str, int] = 'POINTS'):
+def delete(type: typing.Union[int, str] = 'POINTS'):
     ''' Delete selected Grease Pencil strokes, vertices, or frames
 
     :param type: Type, Method used for deleting Grease Pencil data * POINTS Points, Delete selected points and split strokes into segments. * STROKES Strokes, Delete selected strokes. * FRAME Frame, Delete active frame.
-    :type type: typing.Union[str, int]
+    :type type: typing.Union[int, str]
     '''
 
     pass
@@ -184,14 +184,14 @@ def dissolve():
     pass
 
 
-def draw(mode: typing.Union[str, int] = 'DRAW',
+def draw(mode: typing.Union[int, str] = 'DRAW',
          stroke: typing.Union[typing.List['bpy.types.OperatorStrokeElement'],
                               'bpy_prop_collection'] = None,
          wait_for_input: bool = True):
     ''' Make annotations on the active data
 
     :param mode: Mode, Way to interpret mouse movements * DRAW Draw Freehand, Draw freehand stroke(s). * DRAW_STRAIGHT Draw Straight Lines, Draw straight line segment(s). * DRAW_POLY Draw Poly Line, Click to place endpoints of straight line segments (connected). * ERASER Eraser, Erase Grease Pencil strokes.
-    :type mode: typing.Union[str, int]
+    :type mode: typing.Union[int, str]
     :param stroke: Stroke
     :type stroke: typing.Union[typing.List['bpy.types.OperatorStrokeElement'], 'bpy_prop_collection']
     :param wait_for_input: Wait for Input, Wait for first click instead of painting immediately
@@ -245,11 +245,11 @@ def layer_add():
     pass
 
 
-def layer_change(layer: typing.Union[str, int] = 'DEFAULT'):
+def layer_change(layer: typing.Union[int, str] = 'DEFAULT'):
     ''' Change active Grease Pencil layer
 
     :param layer: Grease Pencil Layer
-    :type layer: typing.Union[str, int]
+    :type layer: typing.Union[int, str]
     '''
 
     pass
@@ -281,11 +281,11 @@ def layer_merge():
     pass
 
 
-def layer_move(type: typing.Union[str, int] = 'UP'):
+def layer_move(type: typing.Union[int, str] = 'UP'):
     ''' Move the active Grease Pencil layer up/down in the list
 
     :param type: Type
-    :type type: typing.Union[str, int]
+    :type type: typing.Union[int, str]
     '''
 
     pass
@@ -307,11 +307,11 @@ def lock_all():
     pass
 
 
-def move_to_layer(layer: typing.Union[str, int] = 'DEFAULT'):
+def move_to_layer(layer: typing.Union[int, str] = 'DEFAULT'):
     ''' Move selected strokes to another layer
 
     :param layer: Grease Pencil Layer
-    :type layer: typing.Union[str, int]
+    :type layer: typing.Union[int, str]
     '''
 
     pass
@@ -325,11 +325,11 @@ def palette_add():
     pass
 
 
-def palette_change(palette: typing.Union[str, int] = 'DEFAULT'):
+def palette_change(palette: typing.Union[int, str] = 'DEFAULT'):
     ''' Change active Grease Pencil palette
 
     :param palette: Grease Pencil Palette
-    :type palette: typing.Union[str, int]
+    :type palette: typing.Union[int, str]
     '''
 
     pass
@@ -395,11 +395,11 @@ def palettecolor_lock_all():
     pass
 
 
-def palettecolor_move(direction: typing.Union[str, int] = 'UP'):
+def palettecolor_move(direction: typing.Union[int, str] = 'UP'):
     ''' Move the active Grease Pencil palette color up/down in the list
 
     :param direction: Direction
-    :type direction: typing.Union[str, int]
+    :type direction: typing.Union[int, str]
     '''
 
     pass
@@ -437,11 +437,11 @@ def palettecolor_unlock_all():
     pass
 
 
-def paste(type: typing.Union[str, int] = 'COPY'):
+def paste(type: typing.Union[int, str] = 'COPY'):
     ''' Paste previously copied strokes or copy and merge in active layer
 
     :param type: Type
-    :type type: typing.Union[str, int]
+    :type type: typing.Union[int, str]
     '''
 
     pass
@@ -485,11 +485,11 @@ def select(extend: bool = False,
     pass
 
 
-def select_all(action: typing.Union[str, int] = 'TOGGLE'):
+def select_all(action: typing.Union[int, str] = 'TOGGLE'):
     ''' Change selection of all Grease Pencil strokes currently visible
 
     :param action: Action, Selection action to execute * TOGGLE Toggle, Toggle selection for all elements. * SELECT Select, Select all elements. * DESELECT Deselect, Deselect all elements. * INVERT Invert, Invert selection of all elements.
-    :type action: typing.Union[str, int]
+    :type action: typing.Union[int, str]
     '''
 
     pass
@@ -551,11 +551,11 @@ def select_first(only_selected_strokes: bool = False, extend: bool = False):
     pass
 
 
-def select_grouped(type: typing.Union[str, int] = 'LAYER'):
+def select_grouped(type: typing.Union[int, str] = 'LAYER'):
     ''' Select all strokes with similar characteristics
 
     :param type: Type * LAYER Layer, Shared layers. * COLOR Color, Shared colors.
-    :type type: typing.Union[str, int]
+    :type type: typing.Union[int, str]
     '''
 
     pass
@@ -656,11 +656,11 @@ def stroke_apply_thickness():
     pass
 
 
-def stroke_arrange(direction: typing.Union[str, int] = 'UP'):
+def stroke_arrange(direction: typing.Union[int, str] = 'UP'):
     ''' Arrange selected strokes up/down in the drawing order of the active layer
 
     :param direction: Direction
-    :type direction: typing.Union[str, int]
+    :type direction: typing.Union[int, str]
     '''
 
     pass
@@ -674,11 +674,11 @@ def stroke_change_color():
     pass
 
 
-def stroke_cyclical_set(type: typing.Union[str, int] = 'TOGGLE'):
+def stroke_cyclical_set(type: typing.Union[int, str] = 'TOGGLE'):
     ''' Close or open the selected stroke adding an edge from last to first point
 
     :param type: Type
-    :type type: typing.Union[str, int]
+    :type type: typing.Union[int, str]
     '''
 
     pass
@@ -692,12 +692,12 @@ def stroke_flip():
     pass
 
 
-def stroke_join(type: typing.Union[str, int] = 'JOIN',
+def stroke_join(type: typing.Union[int, str] = 'JOIN',
                 leave_gaps: bool = False):
     ''' Join selected strokes (optionally as new stroke)
 
     :param type: Type
-    :type type: typing.Union[str, int]
+    :type type: typing.Union[int, str]
     :param leave_gaps: Leave Gaps, Leave gaps between joined strokes instead of linking them
     :type leave_gaps: bool
     '''
