@@ -24,8 +24,8 @@ def ply(filepath: str = "",
 
 
 def stl(filepath: str = "",
-        axis_forward: typing.Union[str, int] = 'Y',
-        axis_up: typing.Union[str, int] = 'Z',
+        axis_forward: typing.Union[int, str] = 'Y',
+        axis_up: typing.Union[int, str] = 'Z',
         filter_glob: str = "*.stl",
         files: typing.Union[typing.List['bpy.types.OperatorFileListElement'],
                             'bpy_prop_collection'] = None,
@@ -38,9 +38,9 @@ def stl(filepath: str = "",
     :param filepath: File Path, Filepath used for importing the file
     :type filepath: str
     :param axis_forward: Forward
-    :type axis_forward: typing.Union[str, int]
+    :type axis_forward: typing.Union[int, str]
     :param axis_up: Up
-    :type axis_up: typing.Union[str, int]
+    :type axis_up: typing.Union[int, str]
     :param filter_glob: filter_glob
     :type filter_glob: str
     :param files: File Path
