@@ -2,11 +2,11 @@ import sys
 import typing
 
 
-def flip(axis: typing.Union[str, int] = 'U'):
+def flip(axis: typing.Union[int, str] = 'U'):
     ''' Mirror all control points without inverting the lattice deform
 
     :param axis: Flip Axis, Coordinates along this axis get flipped
-    :type axis: typing.Union[str, int]
+    :type axis: typing.Union[int, str]
     '''
 
     pass
@@ -20,11 +20,11 @@ def make_regular():
     pass
 
 
-def select_all(action: typing.Union[str, int] = 'TOGGLE'):
+def select_all(action: typing.Union[int, str] = 'TOGGLE'):
     ''' Change selection of all UVW control points
 
     :param action: Action, Selection action to execute * TOGGLE Toggle, Toggle selection for all elements. * SELECT Select, Select all elements. * DESELECT Deselect, Deselect all elements. * INVERT Invert, Invert selection of all elements.
-    :type action: typing.Union[str, int]
+    :type action: typing.Union[int, str]
     '''
 
     pass
@@ -38,12 +38,12 @@ def select_less():
     pass
 
 
-def select_mirror(axis: typing.Union[typing.Set[str], typing.Set[int]] = {'X'},
+def select_mirror(axis: typing.Union[typing.Set[int], typing.Set[str]] = {'X'},
                   extend: bool = False):
     ''' Select mirrored lattice points
 
     :param axis: Axis
-    :type axis: typing.Union[typing.Set[str], typing.Set[int]]
+    :type axis: typing.Union[typing.Set[int], typing.Set[str]]
     :param extend: Extend, Extend the selection
     :type extend: bool
     '''
@@ -61,7 +61,7 @@ def select_more():
 
 def select_random(percent: float = 50.0,
                   seed: int = 0,
-                  action: typing.Union[str, int] = 'SELECT'):
+                  action: typing.Union[int, str] = 'SELECT'):
     ''' Randomly select UVW control points
 
     :param percent: Percent, Percentage of objects to select randomly
@@ -69,7 +69,7 @@ def select_random(percent: float = 50.0,
     :param seed: Random Seed, Seed for the random number generator
     :type seed: int
     :param action: Action, Selection action to execute * SELECT Select, Select all elements. * DESELECT Deselect, Deselect all elements.
-    :type action: typing.Union[str, int]
+    :type action: typing.Union[int, str]
     '''
 
     pass
