@@ -1,11 +1,12 @@
 import sys
 import typing
+import bpy.types
 
 
 def add_feather_vertex(location: typing.List[float] = (0.0, 0.0)):
-    '''Add vertex to feather 
+    ''' Add vertex to feather
 
-    :param location: Location, Location of vertex in normalized space 
+    :param location: Location, Location of vertex in normalized space
     :type location: typing.List[float]
     '''
 
@@ -14,19 +15,19 @@ def add_feather_vertex(location: typing.List[float] = (0.0, 0.0)):
 
 def add_feather_vertex_slide(MASK_OT_add_feather_vertex=None,
                              MASK_OT_slide_point=None):
-    '''Add new vertex to feather and slide it 
+    ''' Add new vertex to feather and slide it
 
-    :param MASK_OT_add_feather_vertex: Add Feather Vertex, Add vertex to feather 
-    :param MASK_OT_slide_point: Slide Point, Slide control points 
+    :param MASK_OT_add_feather_vertex: Add Feather Vertex, Add vertex to feather
+    :param MASK_OT_slide_point: Slide Point, Slide control points
     '''
 
     pass
 
 
 def add_vertex(location: typing.List[float] = (0.0, 0.0)):
-    '''Add vertex to active spline 
+    ''' Add vertex to active spline
 
-    :param location: Location, Location of vertex in normalized space 
+    :param location: Location, Location of vertex in normalized space
     :type location: typing.List[float]
     '''
 
@@ -34,17 +35,17 @@ def add_vertex(location: typing.List[float] = (0.0, 0.0)):
 
 
 def add_vertex_slide(MASK_OT_add_vertex=None, MASK_OT_slide_point=None):
-    '''Add new vertex and slide it 
+    ''' Add new vertex and slide it
 
-    :param MASK_OT_add_vertex: Add Vertex, Add vertex to active spline 
-    :param MASK_OT_slide_point: Slide Point, Slide control points 
+    :param MASK_OT_add_vertex: Add Vertex, Add vertex to active spline
+    :param MASK_OT_slide_point: Slide Point, Slide control points
     '''
 
     pass
 
 
 def copy_splines():
-    '''Copy selected splines to clipboard 
+    ''' Copy selected splines to clipboard
 
     '''
 
@@ -52,7 +53,7 @@ def copy_splines():
 
 
 def cyclic_toggle():
-    '''Toggle cyclic for selected splines 
+    ''' Toggle cyclic for selected splines
 
     '''
 
@@ -60,7 +61,7 @@ def cyclic_toggle():
 
 
 def delete():
-    '''Delete selected control points or splines 
+    ''' Delete selected control points or splines
 
     '''
 
@@ -68,7 +69,7 @@ def delete():
 
 
 def duplicate():
-    '''Duplicate selected control points and segments between them 
+    ''' Duplicate selected control points and segments between them
 
     '''
 
@@ -76,17 +77,17 @@ def duplicate():
 
 
 def duplicate_move(MASK_OT_duplicate=None, TRANSFORM_OT_translate=None):
-    '''Duplicate mask and move 
+    ''' Duplicate mask and move
 
-    :param MASK_OT_duplicate: Duplicate Mask, Duplicate selected control points and segments between them 
-    :param TRANSFORM_OT_translate: Translate, Translate (move) selected items 
+    :param MASK_OT_duplicate: Duplicate Mask, Duplicate selected control points and segments between them
+    :param TRANSFORM_OT_translate: Translate, Translate (move) selected items
     '''
 
     pass
 
 
 def feather_weight_clear():
-    '''Reset the feather weight to zero 
+    ''' Reset the feather weight to zero
 
     '''
 
@@ -94,9 +95,9 @@ def feather_weight_clear():
 
 
 def handle_type_set(type: typing.Union[int, str] = 'AUTO'):
-    '''Set type of handles for selected control points 
+    ''' Set type of handles for selected control points
 
-    :param type: Type, Spline type 
+    :param type: Type, Spline type
     :type type: typing.Union[int, str]
     '''
 
@@ -104,7 +105,7 @@ def handle_type_set(type: typing.Union[int, str] = 'AUTO'):
 
 
 def hide_view_clear():
-    '''Reveal the layer by setting the hide flag 
+    ''' Reveal the layer by setting the hide flag
 
     '''
 
@@ -112,9 +113,9 @@ def hide_view_clear():
 
 
 def hide_view_set(unselected: bool = False):
-    '''Hide the layer by setting the hide flag 
+    ''' Hide the layer by setting the hide flag
 
-    :param unselected: Unselected, Hide unselected rather than selected layers 
+    :param unselected: Unselected, Hide unselected rather than selected layers
     :type unselected: bool
     '''
 
@@ -122,9 +123,9 @@ def hide_view_set(unselected: bool = False):
 
 
 def layer_move(direction: typing.Union[int, str] = 'UP'):
-    '''Move the active layer up/down in the list 
+    ''' Move the active layer up/down in the list
 
-    :param direction: Direction, Direction to move the active layer 
+    :param direction: Direction, Direction to move the active layer
     :type direction: typing.Union[int, str]
     '''
 
@@ -132,9 +133,9 @@ def layer_move(direction: typing.Union[int, str] = 'UP'):
 
 
 def layer_new(name: str = ""):
-    '''Add new mask layer for masking 
+    ''' Add new mask layer for masking
 
-    :param name: Name, Name of new mask layer 
+    :param name: Name, Name of new mask layer
     :type name: str
     '''
 
@@ -142,7 +143,7 @@ def layer_new(name: str = ""):
 
 
 def layer_remove():
-    '''Remove mask layer 
+    ''' Remove mask layer
 
     '''
 
@@ -150,9 +151,9 @@ def layer_remove():
 
 
 def new(name: str = ""):
-    '''Create new mask 
+    ''' Create new mask
 
-    :param name: Name, Name of new mask 
+    :param name: Name, Name of new mask
     :type name: str
     '''
 
@@ -160,7 +161,7 @@ def new(name: str = ""):
 
 
 def normals_make_consistent():
-    '''Re-calculate the direction of selected handles 
+    ''' Re-calculate the direction of selected handles
 
     '''
 
@@ -168,7 +169,7 @@ def normals_make_consistent():
 
 
 def parent_clear():
-    '''Clear the mask’s parenting 
+    ''' Clear the mask's parenting
 
     '''
 
@@ -176,7 +177,7 @@ def parent_clear():
 
 
 def parent_set():
-    '''Set the mask’s parenting 
+    ''' Set the mask's parenting
 
     '''
 
@@ -184,7 +185,7 @@ def parent_set():
 
 
 def paste_splines():
-    '''Paste splines from clipboard 
+    ''' Paste splines from clipboard
 
     '''
 
@@ -193,11 +194,11 @@ def paste_splines():
 
 def primitive_circle_add(size: float = 100.0,
                          location: typing.List[float] = (0.0, 0.0)):
-    '''Add new circle-shaped spline 
+    ''' Add new circle-shaped spline
 
-    :param size: Size, Size of new circle 
+    :param size: Size, Size of new circle
     :type size: float
-    :param location: Location, Location of new circle 
+    :param location: Location, Location of new circle
     :type location: typing.List[float]
     '''
 
@@ -206,11 +207,11 @@ def primitive_circle_add(size: float = 100.0,
 
 def primitive_square_add(size: float = 100.0,
                          location: typing.List[float] = (0.0, 0.0)):
-    '''Add new square-shaped spline 
+    ''' Add new square-shaped spline
 
-    :param size: Size, Size of new circle 
+    :param size: Size, Size of new circle
     :type size: float
-    :param location: Location, Location of new circle 
+    :param location: Location, Location of new circle
     :type location: typing.List[float]
     '''
 
@@ -221,15 +222,15 @@ def select(extend: bool = False,
            deselect: bool = False,
            toggle: bool = False,
            location: typing.List[float] = (0.0, 0.0)):
-    '''Select spline points 
+    ''' Select spline points
 
-    :param extend: Extend, Extend selection instead of deselecting everything first 
+    :param extend: Extend, Extend selection instead of deselecting everything first
     :type extend: bool
-    :param deselect: Deselect, Remove from selection 
+    :param deselect: Deselect, Remove from selection
     :type deselect: bool
-    :param toggle: Toggle Selection, Toggle the selection 
+    :param toggle: Toggle Selection, Toggle the selection
     :type toggle: bool
-    :param location: Location, Location of vertex in normalized space 
+    :param location: Location, Location of vertex in normalized space
     :type location: typing.List[float]
     '''
 
@@ -237,9 +238,9 @@ def select(extend: bool = False,
 
 
 def select_all(action: typing.Union[int, str] = 'TOGGLE'):
-    '''Change selection of all curve points 
+    ''' Change selection of all curve points
 
-    :param action: Action, Selection action to executeTOGGLE Toggle, Toggle selection for all elements.SELECT Select, Select all elements.DESELECT Deselect, Deselect all elements.INVERT Invert, Invert selection of all elements. 
+    :param action: Action, Selection action to execute * TOGGLE Toggle, Toggle selection for all elements. * SELECT Select, Select all elements. * DESELECT Deselect, Deselect all elements. * INVERT Invert, Invert selection of all elements.
     :type action: typing.Union[int, str]
     '''
 
@@ -252,19 +253,19 @@ def select_border(gesture_mode: int = 0,
                   ymin: int = 0,
                   ymax: int = 0,
                   extend: bool = True):
-    '''Select curve points using border selection 
+    ''' Select curve points using border selection
 
-    :param gesture_mode: Gesture Mode 
+    :param gesture_mode: Gesture Mode
     :type gesture_mode: int
-    :param xmin: X Min 
+    :param xmin: X Min
     :type xmin: int
-    :param xmax: X Max 
+    :param xmax: X Max
     :type xmax: int
-    :param ymin: Y Min 
+    :param ymin: Y Min
     :type ymin: int
-    :param ymax: Y Max 
+    :param ymax: Y Max
     :type ymax: int
-    :param extend: Extend, Extend selection instead of deselecting everything first 
+    :param extend: Extend, Extend selection instead of deselecting everything first
     :type extend: bool
     '''
 
@@ -275,15 +276,15 @@ def select_circle(x: int = 0,
                   y: int = 0,
                   radius: int = 1,
                   gesture_mode: int = 0):
-    '''Select curve points using circle selection 
+    ''' Select curve points using circle selection
 
-    :param x: X 
+    :param x: X
     :type x: int
-    :param y: Y 
+    :param y: Y
     :type y: int
-    :param radius: Radius 
+    :param radius: Radius
     :type radius: int
-    :param gesture_mode: Gesture Mode 
+    :param gesture_mode: Gesture Mode
     :type gesture_mode: int
     '''
 
@@ -294,13 +295,13 @@ def select_lasso(path: typing.Union[typing.List['bpy.types.OperatorMousePath'],
                                     'bpy_prop_collection'] = None,
                  deselect: bool = False,
                  extend: bool = True):
-    '''Select curve points using lasso selection 
+    ''' Select curve points using lasso selection
 
-    :param path: Path 
+    :param path: Path
     :type path: typing.Union[typing.List['bpy.types.OperatorMousePath'], 'bpy_prop_collection']
-    :param deselect: Deselect, Deselect rather than select items 
+    :param deselect: Deselect, Deselect rather than select items
     :type deselect: bool
-    :param extend: Extend, Extend selection instead of deselecting everything first 
+    :param extend: Extend, Extend selection instead of deselecting everything first
     :type extend: bool
     '''
 
@@ -308,7 +309,7 @@ def select_lasso(path: typing.Union[typing.List['bpy.types.OperatorMousePath'],
 
 
 def select_less():
-    '''Deselect spline points at the boundary of each selection region 
+    ''' Deselect spline points at the boundary of each selection region
 
     '''
 
@@ -316,7 +317,7 @@ def select_less():
 
 
 def select_linked():
-    '''Select all curve points linked to already selected ones 
+    ''' Select all curve points linked to already selected ones
 
     '''
 
@@ -324,9 +325,9 @@ def select_linked():
 
 
 def select_linked_pick(deselect: bool = False):
-    '''(De)select all points linked to the curve under the mouse cursor 
+    ''' (De)select all points linked to the curve under the mouse cursor
 
-    :param deselect: Deselect 
+    :param deselect: Deselect
     :type deselect: bool
     '''
 
@@ -334,7 +335,7 @@ def select_linked_pick(deselect: bool = False):
 
 
 def select_more():
-    '''Select more spline points connected to initial selection 
+    ''' Select more spline points connected to initial selection
 
     '''
 
@@ -342,7 +343,7 @@ def select_more():
 
 
 def shape_key_clear():
-    '''Undocumented 
+    ''' Undocumented
 
     '''
 
@@ -350,7 +351,7 @@ def shape_key_clear():
 
 
 def shape_key_feather_reset():
-    '''Reset feather weights on all selected points animation values 
+    ''' Reset feather weights on all selected points animation values
 
     '''
 
@@ -358,7 +359,7 @@ def shape_key_feather_reset():
 
 
 def shape_key_insert():
-    '''Undocumented 
+    ''' Undocumented
 
     '''
 
@@ -366,11 +367,11 @@ def shape_key_insert():
 
 
 def shape_key_rekey(location: bool = True, feather: bool = True):
-    '''Recalculate animation data on selected points for frames selected in the dopesheet 
+    ''' Recalculate animation data on selected points for frames selected in the dopesheet
 
-    :param location: Location 
+    :param location: Location
     :type location: bool
-    :param feather: Feather 
+    :param feather: Feather
     :type feather: bool
     '''
 
@@ -378,11 +379,11 @@ def shape_key_rekey(location: bool = True, feather: bool = True):
 
 
 def slide_point(slide_feather: bool = False, is_new_point: bool = False):
-    '''Slide control points 
+    ''' Slide control points
 
-    :param slide_feather: Slide Feather, First try to slide feather instead of vertex 
+    :param slide_feather: Slide Feather, First try to slide feather instead of vertex
     :type slide_feather: bool
-    :param is_new_point: Slide New Point, Newly created vertex is being slid 
+    :param is_new_point: Slide New Point, Newly created vertex is being slid
     :type is_new_point: bool
     '''
 
@@ -390,7 +391,7 @@ def slide_point(slide_feather: bool = False, is_new_point: bool = False):
 
 
 def slide_spline_curvature():
-    '''Slide a point on the spline to define it’s curvature 
+    ''' Slide a point on the spline to define it's curvature
 
     '''
 
@@ -398,7 +399,7 @@ def slide_spline_curvature():
 
 
 def switch_direction():
-    '''Switch direction of selected splines 
+    ''' Switch direction of selected splines
 
     '''
 
