@@ -42,8 +42,8 @@ def add_file(filepath: str = "",
              relative_path: bool = True,
              show_multiview: bool = False,
              use_multiview: bool = False,
-             display_type: typing.Union[str, int] = 'DEFAULT',
-             sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA',
+             display_type: typing.Union[int, str] = 'DEFAULT',
+             sort_method: typing.Union[int, str] = 'FILE_SORT_ALPHA',
              name: str = "Image"):
     ''' Add a file node to the current node editor
 
@@ -84,9 +84,9 @@ def add_file(filepath: str = "",
     :param use_multiview: Use Multi-View
     :type use_multiview: bool
     :param display_type: Display Type * DEFAULT Default, Automatically determine display type for files. * LIST_SHORT Short List, Display files as short list. * LIST_LONG Long List, Display files as a detailed list. * THUMBNAIL Thumbnails, Display files as thumbnails.
-    :type display_type: typing.Union[str, int]
+    :type display_type: typing.Union[int, str]
     :param sort_method: File sorting mode * FILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically. * FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type. * FILE_SORT_TIME Sort by time, Sort files by modification time. * FILE_SORT_SIZE Sort by size, Sort files by size.
-    :type sort_method: typing.Union[str, int]
+    :type sort_method: typing.Union[int, str]
     :param name: Name, Datablock name to assign
     :type name: str
     '''
@@ -139,7 +139,7 @@ def add_search(type: str = "",
                settings: typing.Union[typing.List['bpy.types.NodeSetting'],
                                       'bpy_prop_collection'] = None,
                use_transform: bool = False,
-               node_item: typing.Union[str, int] = ''):
+               node_item: typing.Union[int, str] = ''):
     ''' Add a node to the active tree
 
     :param type: Node Type, Node type
@@ -149,7 +149,7 @@ def add_search(type: str = "",
     :param use_transform: Use Transform, Start transform operator after inserting the node
     :type use_transform: bool
     :param node_item: Node Type, Node type
-    :type node_item: typing.Union[str, int]
+    :type node_item: typing.Union[int, str]
     '''
 
     pass
@@ -222,7 +222,7 @@ def clipboard_paste():
 
 
 def collapse_hide_unused_toggle():
-    ''' Toggle collapsed nodes and hide unused sockets
+    ''' Toggle collapsed nodes and hide unused sockets :file: startup/bl_operators/node.py <https://developer.blender.org/diffusion/B/browse/master/release/scripts/ /startup/bl_operators/node.py> _:262
 
     '''
 
@@ -333,11 +333,11 @@ def group_make():
     pass
 
 
-def group_separate(type: typing.Union[str, int] = 'COPY'):
+def group_separate(type: typing.Union[int, str] = 'COPY'):
     ''' Separate selected nodes from the node group
 
     :param type: Type * COPY Copy, Copy to parent node tree, keep group intact. * MOVE Move, Move to parent node tree, remove from group.
-    :type type: typing.Union[str, int]
+    :type type: typing.Union[int, str]
     '''
 
     pass
@@ -465,11 +465,11 @@ def mute_toggle():
     pass
 
 
-def new_node_tree(type: typing.Union[str, int] = '', name: str = "NodeTree"):
+def new_node_tree(type: typing.Union[int, str] = '', name: str = "NodeTree"):
     ''' Create a new node tree
 
     :param type: Tree Type
-    :type type: typing.Union[str, int]
+    :type type: typing.Union[int, str]
     :param name: Name
     :type name: str
     '''
@@ -515,11 +515,11 @@ def output_file_add_socket(file_path: str = "Image"):
     pass
 
 
-def output_file_move_active_socket(direction: typing.Union[str, int] = 'DOWN'):
+def output_file_move_active_socket(direction: typing.Union[int, str] = 'DOWN'):
     ''' Move the active input of a file output node up or down the list
 
     :param direction: Direction
-    :type direction: typing.Union[str, int]
+    :type direction: typing.Union[int, str]
     '''
 
     pass
@@ -603,11 +603,11 @@ def select(mouse_x: int = 0, mouse_y: int = 0, extend: bool = False):
     pass
 
 
-def select_all(action: typing.Union[str, int] = 'TOGGLE'):
+def select_all(action: typing.Union[int, str] = 'TOGGLE'):
     ''' (De)select all nodes
 
     :param action: Action, Selection action to execute * TOGGLE Toggle, Toggle selection for all elements. * SELECT Select, Select all elements. * DESELECT Deselect, Deselect all elements. * INVERT Invert, Invert selection of all elements.
-    :type action: typing.Union[str, int]
+    :type action: typing.Union[int, str]
     '''
 
     pass
@@ -661,13 +661,13 @@ def select_circle(x: int = 0,
 
 
 def select_grouped(extend: bool = False,
-                   type: typing.Union[str, int] = 'TYPE'):
+                   type: typing.Union[int, str] = 'TYPE'):
     ''' Select nodes with similar properties
 
     :param extend: Extend, Extend selection instead of deselecting everything first
     :type extend: bool
     :param type: Type
-    :type type: typing.Union[str, int]
+    :type type: typing.Union[int, str]
     '''
 
     pass
@@ -777,28 +777,28 @@ def translate_attach_remove_on_cancel(TRANSFORM_OT_translate=None,
 
 
 def tree_path_parent():
-    ''' Go to parent node tree
+    ''' Go to parent node tree :file: startup/bl_operators/node.py <https://developer.blender.org/diffusion/B/browse/master/release/scripts/ /startup/bl_operators/node.py> _:292
 
     '''
 
     pass
 
 
-def tree_socket_add(in_out: typing.Union[str, int] = 'IN'):
+def tree_socket_add(in_out: typing.Union[int, str] = 'IN'):
     ''' Add an input or output socket to the current node tree
 
     :param in_out: Socket Type
-    :type in_out: typing.Union[str, int]
+    :type in_out: typing.Union[int, str]
     '''
 
     pass
 
 
-def tree_socket_move(direction: typing.Union[str, int] = 'UP'):
+def tree_socket_move(direction: typing.Union[int, str] = 'UP'):
     ''' Move a socket up or down in the current node tree's sockets stack
 
     :param direction: Direction
-    :type direction: typing.Union[str, int]
+    :type direction: typing.Union[int, str]
     '''
 
     pass
