@@ -1,8 +1,8 @@
 import sys
 import typing
-from . import interpolate
-from . import kdtree
 from . import geometry
+from . import kdtree
+from . import interpolate
 from . import noise
 from . import bvhtree
 
@@ -156,11 +156,11 @@ class Euler:
         '''
         pass
 
-    def rotate(self, other: typing.Union['Euler', 'Matrix', 'Quaternion']):
+    def rotate(self, other: typing.Union['Euler', 'Quaternion', 'Matrix']):
         ''' Rotates the euler by another mathutils value.
 
         :param other: rotation component of mathutils value
-        :type other: typing.Union['Euler', 'Matrix', 'Quaternion']
+        :type other: typing.Union['Euler', 'Quaternion', 'Matrix']
         '''
         pass
 
@@ -462,11 +462,11 @@ class Matrix:
         '''
         pass
 
-    def rotate(self, other: typing.Union['Euler', 'Matrix', 'Quaternion']):
+    def rotate(self, other: typing.Union['Euler', 'Quaternion', 'Matrix']):
         ''' Rotates the matrix by another mathutils value.
 
         :param other: rotation component of mathutils value
-        :type other: typing.Union['Euler', 'Matrix', 'Quaternion']
+        :type other: typing.Union['Euler', 'Quaternion', 'Matrix']
         '''
         pass
 
@@ -710,11 +710,11 @@ class Quaternion:
         '''
         pass
 
-    def rotate(self, other: typing.Union['Euler', 'Matrix', 'Quaternion']):
+    def rotate(self, other: typing.Union['Euler', 'Quaternion', 'Matrix']):
         ''' Rotates the quaternion by another mathutils value.
 
         :param other: rotation component of mathutils value
-        :type other: typing.Union['Euler', 'Matrix', 'Quaternion']
+        :type other: typing.Union['Euler', 'Quaternion', 'Matrix']
         '''
         pass
 
@@ -763,7 +763,7 @@ class Quaternion:
         pass
 
     def to_exponential_map(self) -> 'Vector':
-        ''' Return the exponential map representation of the quaternion. This representation consist of the rotation axis multiplied by the rotation angle. Such a representation is useful for interpolation between multiple orientations.
+        ''' Return the exponential map representation of the quaternion. This representation consist of the rotation axis multiplied by the rotation angle. Such a representation is useful for interpolation between multiple orientations. To convert back to a quaternion, pass it to the Quaternion constructor.
 
         :rtype: 'Vector'
         :return: exponential map.
@@ -2059,11 +2059,11 @@ class Vector:
         pass
 
     @staticmethod
-    def rotate(other: typing.Union['Euler', 'Matrix', 'Quaternion']):
+    def rotate(other: typing.Union['Euler', 'Quaternion', 'Matrix']):
         ''' Rotate the vector by a rotation value.
 
         :param other: rotation component of mathutils value
-        :type other: typing.Union['Euler', 'Matrix', 'Quaternion']
+        :type other: typing.Union['Euler', 'Quaternion', 'Matrix']
         '''
         pass
 
